@@ -228,9 +228,7 @@ impl<'de> Visitor<'de> for OptionVisitor {
 
         Ok(match kind {
             CommandOptionType::SubCommand => {
-                let options = options
-                    .flatten()
-                    .ok_or_else(|| DeError::missing_field("options"))?;
+                let options = options.flatten().unwrap_or_default();
 
                 CommandOption::SubCommand(OptionsCommandOptionData {
                     description,
@@ -240,9 +238,7 @@ impl<'de> Visitor<'de> for OptionVisitor {
                 })
             }
             CommandOptionType::SubCommandGroup => {
-                let options = options
-                    .flatten()
-                    .ok_or_else(|| DeError::missing_field("options"))?;
+                let options = options.flatten().unwrap_or_default();
 
                 CommandOption::SubCommandGroup(OptionsCommandOptionData {
                     description,
@@ -251,30 +247,18 @@ impl<'de> Visitor<'de> for OptionVisitor {
                     required,
                 })
             }
-            CommandOptionType::String => {
-                let choices = choices
-                    .flatten()
-                    .ok_or_else(|| DeError::missing_field("choices"))?;
-
-                CommandOption::String(ChoiceCommandOptionData {
-                    choices,
-                    description,
-                    name,
-                    required,
-                })
-            }
-            CommandOptionType::Integer => {
-                let choices = choices
-                    .flatten()
-                    .ok_or_else(|| DeError::missing_field("choices"))?;
-
-                CommandOption::Integer(ChoiceCommandOptionData {
-                    choices,
-                    description,
-                    name,
-                    required,
-                })
-            }
+            CommandOptionType::String => CommandOption::String(ChoiceCommandOptionData {
+                choices: choices.flatten().unwrap_or_default(),
+                description,
+                name,
+                required,
+            }),
+            CommandOptionType::Integer => CommandOption::Integer(ChoiceCommandOptionData {
+                choices: choices.flatten().unwrap_or_default(),
+                description,
+                name,
+                required,
+            }),
             CommandOptionType::Boolean => CommandOption::Boolean(BaseCommandOptionData {
                 description,
                 name,
@@ -356,6 +340,8 @@ pub struct ChoiceCommandOptionData {
     ///
     /// When completing this option, the user is prompted with a selector of all
     /// available choices.
+    ///
+    /// If no choices are available, the user must input a value manually.
     #[serde(default)]
     pub choices: Vec<CommandOptionChoice>,
     /// Description of the option. It must be 100 characters or less.
@@ -371,7 +357,7 @@ pub struct ChoiceCommandOptionData {
 ///
 /// Refer to [the discord docs] for more information.
 ///
-/// [the discord docs]: https://discord.com/developers/docs/interactions/slash-commands#applicationcommandoptionchoice
+/// [the discord docs]: https://discord.com/developers/docs/interactions/application-commands#applicationcommandoptionchoice
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 #[serde(untagged)]
 pub enum CommandOptionChoice {
@@ -415,18 +401,52 @@ impl CommandOptionType {
 #[cfg(test)]
 mod tests {
     use super::{
-        super::Command, BaseCommandOptionData, ChoiceCommandOptionData, CommandOption,
-        CommandOptionChoice, OptionsCommandOptionData,
+        super::{Command, CommandType},
+        BaseCommandOptionData, ChoiceCommandOptionData, CommandOption, CommandOptionChoice,
+        OptionsCommandOptionData,
     };
     use crate::id::{ApplicationId, CommandId, GuildId};
     use serde_test::Token;
 
+    /// Test that when a subcommand or subcommand group's `options` field is
+    /// missing during deserialization that the field is defaulted instead of
+    /// returning a missing field error.
+    #[test]
+    fn test_issue_1150() {
+        let value = CommandOption::SubCommand(OptionsCommandOptionData {
+            description: "ponyville".to_owned(),
+            name: "equestria".to_owned(),
+            options: Vec::new(),
+            required: false,
+        });
+
+        serde_test::assert_de_tokens(
+            &value,
+            &[
+                Token::Struct {
+                    name: "CommandOptionEnvelope",
+                    len: 4,
+                },
+                Token::Str("description"),
+                Token::Str("ponyville"),
+                Token::Str("name"),
+                Token::Str("equestria"),
+                Token::Str("options"),
+                Token::None,
+                Token::Str("type"),
+                Token::U8(1),
+                Token::StructEnd,
+            ],
+        );
+    }
+
     #[test]
     #[allow(clippy::too_many_lines)]
     fn test_command_option_full() {
         let value = Command {
             application_id: Some(ApplicationId(100)),
             guild_id: Some(GuildId(300)),
+            kind: CommandType::ChatInput,
             name: "test command".into(),
             default_permission: Some(true),
             description: "this command is a test".into(),
@@ -438,6 +458,12 @@ mod tests {
                     description: "sub command desc".into(),
                     name: "sub command name".into(),
                     options: vec![
+                        CommandOption::String(ChoiceCommandOptionData {
+                            choices: Vec::new(),
+                            description: "string manual desc".into(),
+                            name: "string_manual".into(),
+                            required: false,
+                        }),
                         CommandOption::String(ChoiceCommandOptionData {
                             choices: vec![CommandOptionChoice::String {
                                 name: "choicea".into(),
@@ -493,7 +519,7 @@ mod tests {
             &[
                 Token::Struct {
                     name: "Command",
-                    len: 7,
+                    len: 8,
                 },
                 Token::Str("application_id"),
                 Token::Some,
@@ -516,6 +542,8 @@ mod tests {
                 Token::Some,
                 Token::NewtypeStruct { name: "CommandId" },
                 Token::Str("200"),
+                Token::Str("type"),
+                Token::U8(1),
                 Token::Str("options"),
                 Token::Seq { len: Some(1) },
                 Token::Struct {
@@ -539,7 +567,22 @@ mod tests {
                 Token::Str("sub command name"),
                 Token::Str("options"),
                 Token::Some,
-                Token::Seq { len: Some(7) },
+                Token::Seq { len: Some(8) },
+                Token::Struct {
+                    name: "CommandOptionEnvelope",
+                    len: 4,
+                },
+                Token::Str("choices"),
+                Token::Some,
+                Token::Seq { len: Some(0) },
+                Token::SeqEnd,
+                Token::Str("description"),
+                Token::Str("string manual desc"),
+                Token::Str("name"),
+                Token::Str("string_manual"),
+                Token::Str("type"),
+                Token::U8(3),
+                Token::StructEnd,
                 Token::Struct {
                     name: "CommandOptionEnvelope",
                     len: 4,
