@@ -21,7 +21,7 @@ pub use self::{
 use self::sticker::MessageSticker;
 use crate::{
     application::component::Component,
-    channel::{embed::Embed, Attachment, ChannelMention},
+    channel::{embed::Embed, Attachment, Channel, ChannelMention},
     guild::PartialMember,
     id::{ApplicationId, ChannelId, GuildId, MessageId, RoleId, WebhookId},
     user::User,
@@ -79,6 +79,8 @@ pub struct Message {
     #[serde(default)]
     pub sticker_items: Vec<MessageSticker>,
     pub timestamp: String,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub thread: Option<Channel>,
     pub tts: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub webhook_id: Option<WebhookId>,
@@ -158,6 +160,7 @@ mod tests {
             }],
             referenced_message: None,
             timestamp: "2020-02-02T02:02:02.020000+00:00".to_owned(),
+            thread: None,
             tts: false,
             webhook_id: None,
         };
@@ -358,6 +361,7 @@ mod tests {
             }],
             referenced_message: None,
             timestamp: "2020-02-02T02:02:02.020000+00:00".to_owned(),
+            thread: None,
             tts: false,
             webhook_id: Some(WebhookId(1)),
         };
