@@ -2,6 +2,7 @@ pub mod embed;
 pub mod message;
 pub mod permission_overwrite;
 pub mod stage_instance;
+pub mod thread;
 pub mod webhook;
 
 mod attachment;
@@ -35,7 +36,12 @@ pub use self::{
     webhook::{Webhook, WebhookType},
 };
 
-use crate::id::{ChannelId, GuildId, MessageId};
+use crate::{
+    channel::thread::{
+        AutoArchiveDuration, NewsThread, PrivateThread, PublicThread, ThreadMember, ThreadMetadata,
+    },
+    id::{ChannelId, GuildId, MessageId, UserId},
+};
 use serde::{
     de::{Deserializer, Error as DeError, IgnoredAny, MapAccess, Visitor},
     Deserialize, Serialize,
@@ -60,6 +66,7 @@ impl Display for ConversionError {
     }
 }
 
+#[allow(clippy::large_enum_variant)]
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 #[serde(untagged)]
 pub enum Channel {
@@ -105,6 +112,9 @@ impl Channel {
 #[serde(untagged)]
 pub enum GuildChannel {
     Category(CategoryChannel),
+    NewsThread(NewsThread),
+    PrivateThread(PrivateThread),
+    PublicThread(PublicThread),
     Text(TextChannel),
     Voice(VoiceChannel),
     Stage(VoiceChannel),
@@ -115,6 +125,9 @@ impl GuildChannel {
     pub const fn guild_id(&self) -> Option<GuildId> {
         match self {
             Self::Category(category) => category.guild_id,
+            Self::NewsThread(thread) => thread.guild_id,
+            Self::PrivateThread(thread) => thread.guild_id,
+            Self::PublicThread(thread) => thread.guild_id,
             Self::Text(text) => text.guild_id,
             Self::Voice(voice) => voice.guild_id,
             Self::Stage(stage) => stage.guild_id,
@@ -125,6 +138,9 @@ impl GuildChannel {
     pub const fn id(&self) -> ChannelId {
         match self {
             Self::Category(category) => category.id,
+            Self::NewsThread(thread) => thread.id,
+            Self::PrivateThread(thread) => thread.id,
+            Self::PublicThread(thread) => thread.id,
             Self::Text(text) => text.id,
             Self::Voice(voice) => voice.id,
             Self::Stage(stage) => stage.id,
@@ -135,6 +151,9 @@ impl GuildChannel {
     pub const fn kind(&self) -> ChannelType {
         match self {
             Self::Category(c) => c.kind,
+            Self::NewsThread(c) => c.kind,
+            Self::PrivateThread(c) => c.kind,
+            Self::PublicThread(c) => c.kind,
             Self::Text(c) => c.kind,
             Self::Stage(c) | Self::Voice(c) => c.kind,
         }
@@ -144,6 +163,9 @@ impl GuildChannel {
     pub fn name(&self) -> &str {
         match self {
             Self::Category(category) => category.name.as_ref(),
+            Self::NewsThread(thread) => thread.name.as_ref(),
+            Self::PrivateThread(thread) => thread.name.as_ref(),
+            Self::PublicThread(thread) => thread.name.as_ref(),
             Self::Text(text) => text.name.as_ref(),
             Self::Voice(voice) => voice.name.as_ref(),
             Self::Stage(stage) => stage.name.as_ref(),
@@ -155,17 +177,24 @@ impl GuildChannel {
 #[serde(field_identifier, rename_all = "snake_case")]
 enum GuildChannelField {
     Bitrate,
+    DefaultAutoArchiveDuration,
     GuildId,
     Id,
+    Invitable,
     LastMessageId,
     LastPinTimestamp,
+    Member,
+    MemberCount,
+    MessageCount,
     Name,
     Nsfw,
+    OwnerId,
     ParentId,
     PermissionOverwrites,
     Position,
     RateLimitPerUser,
     RtcRegion,
+    ThreadMetadata,
     Topic,
     Type,
     UserLimit,
@@ -186,24 +215,34 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
         const VARIANTS: &[&str] = &[
             "GuildCategory",
             "GuildNews",
+            "GuildNewsThread",
+            "GuildPrivateThread",
+            "GuildPublicThread",
             "GuildStore",
             "GuildText",
             "GuildVoice",
         ];
 
         let mut bitrate = None;
+        let mut default_auto_archive_duration: Option<Option<AutoArchiveDuration>> = None;
         let mut guild_id = None;
         let mut id = None;
+        let mut invitable: Option<Option<bool>> = None;
         let mut kind = None;
         let mut last_message_id: Option<Option<MessageId>> = None;
         let mut last_pin_timestamp: Option<Option<String>> = None;
+        let mut member: Option<Option<ThreadMember>> = None;
+        let mut member_count: Option<u8> = None;
+        let mut message_count: Option<u8> = None;
         let mut name = None;
         let mut nsfw = None;
+        let mut owner_id: Option<Option<UserId>> = None;
         let mut parent_id: Option<Option<ChannelId>> = None;
         let mut permission_overwrites = None;
         let mut position = None;
         let mut rate_limit_per_user = None;
         let mut rtc_region: Option<Option<String>> = None;
+        let mut thread_metadata: Option<ThreadMetadata> = None;
         let mut topic: Option<Option<String>> = None;
         let mut user_limit = None;
         let mut video_quality_mode = None;
@@ -240,6 +279,13 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
 
                     bitrate = Some(map.next_value()?);
                 }
+                GuildChannelField::DefaultAutoArchiveDuration => {
+                    if default_auto_archive_duration.is_some() {
+                        return Err(DeError::duplicate_field("default_auto_archive_duration"));
+                    }
+
+                    default_auto_archive_duration = Some(map.next_value()?);
+                }
                 GuildChannelField::GuildId => {
                     if guild_id.is_some() {
                         return Err(DeError::duplicate_field("guild_id"));
@@ -254,6 +300,13 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
 
                     id = Some(map.next_value()?);
                 }
+                GuildChannelField::Invitable => {
+                    if invitable.is_some() {
+                        return Err(DeError::duplicate_field("invitable"));
+                    }
+
+                    invitable = Some(map.next_value()?);
+                }
                 GuildChannelField::Type => {
                     if kind.is_some() {
                         return Err(DeError::duplicate_field("type"));
@@ -275,6 +328,27 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
 
                     last_pin_timestamp = Some(map.next_value()?);
                 }
+                GuildChannelField::Member => {
+                    if member.is_some() {
+                        return Err(DeError::duplicate_field("member"));
+                    }
+
+                    member = Some(map.next_value()?);
+                }
+                GuildChannelField::MemberCount => {
+                    if member_count.is_some() {
+                        return Err(DeError::duplicate_field("member_count"));
+                    }
+
+                    member_count = Some(map.next_value()?);
+                }
+                GuildChannelField::MessageCount => {
+                    if message_count.is_some() {
+                        return Err(DeError::duplicate_field("message_count"));
+                    }
+
+                    message_count = Some(map.next_value()?);
+                }
                 GuildChannelField::Name => {
                     if name.is_some() {
                         return Err(DeError::duplicate_field("name"));
@@ -289,6 +363,13 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
 
                     nsfw = Some(map.next_value()?);
                 }
+                GuildChannelField::OwnerId => {
+                    if owner_id.is_some() {
+                        return Err(DeError::duplicate_field("owner_id"));
+                    }
+
+                    owner_id = Some(map.next_value()?);
+                }
                 GuildChannelField::ParentId => {
                     if parent_id.is_some() {
                         return Err(DeError::duplicate_field("parent_id"));
@@ -324,6 +405,13 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
 
                     rtc_region = Some(map.next_value()?);
                 }
+                GuildChannelField::ThreadMetadata => {
+                    if thread_metadata.is_some() {
+                        return Err(DeError::duplicate_field("thread_metadata"));
+                    }
+
+                    thread_metadata = Some(map.next_value()?);
+                }
                 GuildChannelField::Topic => {
                     if topic.is_some() {
                         return Err(DeError::duplicate_field("topic"));
@@ -353,9 +441,6 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
         let id = id.ok_or_else(|| DeError::missing_field("id"))?;
         let kind = kind.ok_or_else(|| DeError::missing_field("type"))?;
         let name = name.ok_or_else(|| DeError::missing_field("name"))?;
-        let permission_overwrites =
-            permission_overwrites.ok_or_else(|| DeError::missing_field("permission_overwrites"))?;
-        let position = position.ok_or_else(|| DeError::missing_field("position"))?;
 
         let nsfw = nsfw.unwrap_or_default();
         let parent_id = parent_id.unwrap_or_default();
@@ -366,14 +451,16 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
             %name,
             %nsfw,
             ?parent_id,
-            ?permission_overwrites,
-            %position,
             "common fields of all variants exist"
         );
 
         Ok(match kind {
             ChannelType::GuildCategory => {
-                tracing::trace!("handling category channel");
+                let permission_overwrites = permission_overwrites
+                    .ok_or_else(|| DeError::missing_field("permission_overwrites"))?;
+                let position = position.ok_or_else(|| DeError::missing_field("position"))?;
+
+                tracing::trace!(?permission_overwrites, %position, "handling category channel");
 
                 GuildChannel::Category(CategoryChannel {
                     guild_id,
@@ -386,10 +473,20 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
             }
             ChannelType::GuildVoice | ChannelType::GuildStageVoice => {
                 let bitrate = bitrate.ok_or_else(|| DeError::missing_field("bitrate"))?;
+                let permission_overwrites = permission_overwrites
+                    .ok_or_else(|| DeError::missing_field("permission_overwrites"))?;
+                let position = position.ok_or_else(|| DeError::missing_field("position"))?;
                 let rtc_region = rtc_region.unwrap_or_default();
                 let user_limit = user_limit.ok_or_else(|| DeError::missing_field("user_limit"))?;
 
-                tracing::trace!(%bitrate, ?user_limit, "handling voice channel");
+                tracing::trace!(
+                    %bitrate,
+                    ?permission_overwrites,
+                    %position,
+                    ?user_limit,
+                    "handling voice channel"
+                );
+
                 let voice_channel = VoiceChannel {
                     bitrate,
                     guild_id,
@@ -413,11 +510,16 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
             ChannelType::GuildNews | ChannelType::GuildStore | ChannelType::GuildText => {
                 let last_message_id = last_message_id.unwrap_or_default();
                 let last_pin_timestamp = last_pin_timestamp.unwrap_or_default();
+                let permission_overwrites = permission_overwrites
+                    .ok_or_else(|| DeError::missing_field("permission_overwrites"))?;
+                let position = position.ok_or_else(|| DeError::missing_field("position"))?;
                 let topic = topic.unwrap_or_default();
 
                 tracing::trace!(
                     ?last_message_id,
                     ?last_pin_timestamp,
+                    ?permission_overwrites,
+                    %position,
                     ?topic,
                     "handling news, store, or text channel"
                 );
@@ -437,6 +539,114 @@ impl<'de> Visitor<'de> for GuildChannelVisitor {
                     topic,
                 })
             }
+            ChannelType::GuildNewsThread
+            | ChannelType::GuildPrivateThread
+            | ChannelType::GuildPublicThread => {
+                let default_auto_archive_duration =
+                    default_auto_archive_duration.unwrap_or_default();
+                let last_message_id = last_message_id.unwrap_or_default();
+                let member = member.unwrap_or_default();
+                let member_count = member_count.unwrap_or_default();
+                let message_count = message_count.unwrap_or_default();
+                let owner_id = owner_id.unwrap_or_default();
+                let thread_metadata =
+                    thread_metadata.ok_or_else(|| DeError::missing_field("thread_metadata"))?;
+
+                match kind {
+                    ChannelType::GuildNewsThread => {
+                        tracing::trace!(
+                            ?default_auto_archive_duration,
+                            ?last_message_id,
+                            ?member,
+                            ?member_count,
+                            ?message_count,
+                            ?owner_id,
+                            ?thread_metadata,
+                            "handling news thread"
+                        );
+
+                        GuildChannel::NewsThread(NewsThread {
+                            default_auto_archive_duration,
+                            guild_id,
+                            id,
+                            kind,
+                            last_message_id,
+                            member,
+                            member_count,
+                            message_count,
+                            name,
+                            owner_id,
+                            parent_id,
+                            rate_limit_per_user,
+                            thread_metadata,
+                        })
+                    }
+                    ChannelType::GuildPrivateThread => {
+                        let invitable = invitable.unwrap_or_default();
+                        let permission_overwrites = permission_overwrites.unwrap_or_default();
+
+                        tracing::trace!(
+                            ?default_auto_archive_duration,
+                            ?invitable,
+                            ?last_message_id,
+                            ?member,
+                            ?member_count,
+                            ?message_count,
+                            ?owner_id,
+                            ?permission_overwrites,
+                            ?thread_metadata,
+                            "handling private thread"
+                        );
+
+                        GuildChannel::PrivateThread(PrivateThread {
+                            default_auto_archive_duration,
+                            guild_id,
+                            id,
+                            invitable,
+                            kind,
+                            last_message_id,
+                            member,
+                            member_count,
+                            message_count,
+                            name,
+                            owner_id,
+                            parent_id,
+                            permission_overwrites,
+                            rate_limit_per_user,
+                            thread_metadata,
+                        })
+                    }
+                    ChannelType::GuildPublicThread => {
+                        tracing::trace!(
+                            ?default_auto_archive_duration,
+                            ?last_message_id,
+                            ?member,
+                            ?member_count,
+                            ?message_count,
+                            ?owner_id,
+                            ?thread_metadata,
+                            "handling public thread"
+                        );
+
+                        GuildChannel::PublicThread(PublicThread {
+                            default_auto_archive_duration,
+                            guild_id,
+                            id,
+                            kind,
+                            last_message_id,
+                            member,
+                            member_count,
+                            message_count,
+                            name,
+                            owner_id,
+                            parent_id,
+                            rate_limit_per_user,
+                            thread_metadata,
+                        })
+                    }
+                    _ => unreachable!(),
+                }
+            }
             other => return Err(DeError::unknown_variant(other.name(), VARIANTS)),
         })
     }
@@ -451,11 +661,13 @@ impl<'de> Deserialize<'de> for GuildChannel {
 #[cfg(test)]
 mod tests {
     use super::{
-        CategoryChannel, Channel, ChannelType, Group, GuildChannel, PrivateChannel, TextChannel,
-        VoiceChannel,
+        AutoArchiveDuration, CategoryChannel, Channel, ChannelType, Group, GuildChannel,
+        NewsThread, PrivateChannel, PrivateThread, PublicThread, TextChannel, ThreadMember,
+        ThreadMetadata, VoiceChannel,
     };
     use crate::{
-        channel::permission_overwrite::PermissionOverwrite,
+        channel::permission_overwrite::{PermissionOverwrite, PermissionOverwriteType},
+        guild::Permissions,
         id::{ChannelId, GuildId, MessageId, UserId},
     };
 
@@ -817,4 +1029,205 @@ mod tests {
             .unwrap()
         );
     }
+
+    #[test]
+    fn test_guild_news_thread_deserialization() {
+        let value = GuildChannel::NewsThread(NewsThread {
+            default_auto_archive_duration: Some(AutoArchiveDuration::Hour),
+            guild_id: Some(GuildId(1)),
+            id: ChannelId(6),
+            kind: ChannelType::GuildNewsThread,
+            last_message_id: Some(MessageId(3)),
+            member: Some(ThreadMember {
+                flags: 0_u64,
+                id: Some(ChannelId(4)),
+                join_timestamp: "jointimestamp".into(),
+                member: None,
+                presence: None,
+                user_id: Some(UserId(5)),
+            }),
+            member_count: 50_u8,
+            message_count: 50_u8,
+            name: "newsthread".into(),
+            owner_id: Some(UserId(5)),
+            parent_id: Some(ChannelId(2)),
+            rate_limit_per_user: Some(1000_u64),
+            thread_metadata: ThreadMetadata {
+                archived: false,
+                auto_archive_duration: AutoArchiveDuration::Day,
+                archive_timestamp: "archivetimestamp".into(),
+                invitable: None,
+                locked: false,
+            },
+        });
+
+        assert_eq!(
+            value,
+            serde_json::from_value(serde_json::json!({
+                "id": "6",
+                "guild_id": "1",
+                "type": ChannelType::GuildNewsThread,
+                "last_message_id": "3",
+                "member": {
+                    "flags": 0,
+                    "id": "4",
+                    "join_timestamp": "jointimestamp",
+                    "user_id": "5",
+                },
+                "default_auto_archive_duration": 60,
+                "member_count": 50,
+                "message_count": 50,
+                "name": "newsthread",
+                "owner_id": "5",
+                "parent_id": "2",
+                "rate_limit_per_user": 1000,
+                "thread_metadata": {
+                    "archive_timestamp": "archivetimestamp",
+                    "archived": false,
+                    "auto_archive_duration": AutoArchiveDuration::Day,
+                    "locked": false
+                }
+            }))
+            .unwrap()
+        )
+    }
+
+    #[test]
+    fn test_guild_public_thread_deserialization() {
+        let value = GuildChannel::PublicThread(PublicThread {
+            default_auto_archive_duration: Some(AutoArchiveDuration::Hour),
+            guild_id: Some(GuildId(1)),
+            id: ChannelId(6),
+            kind: ChannelType::GuildPublicThread,
+            last_message_id: Some(MessageId(3)),
+            member: Some(ThreadMember {
+                flags: 0_u64,
+                id: Some(ChannelId(4)),
+                join_timestamp: "jointimestamp".into(),
+                member: None,
+                presence: None,
+                user_id: Some(UserId(5)),
+            }),
+            member_count: 50_u8,
+            message_count: 50_u8,
+            name: "publicthread".into(),
+            owner_id: Some(UserId(5)),
+            parent_id: Some(ChannelId(2)),
+            rate_limit_per_user: Some(1000_u64),
+            thread_metadata: ThreadMetadata {
+                archived: false,
+                auto_archive_duration: AutoArchiveDuration::Day,
+                archive_timestamp: "archivetimestamp".into(),
+                invitable: None,
+                locked: false,
+            },
+        });
+
+        assert_eq!(
+            value,
+            serde_json::from_value(serde_json::json!({
+                "id": "6",
+                "guild_id": "1",
+                "type": ChannelType::GuildPublicThread,
+                "last_message_id": "3",
+                "member": {
+                    "flags": 0,
+                    "id": "4",
+                    "join_timestamp": "jointimestamp",
+                    "user_id": "5",
+                },
+                "default_auto_archive_duration": 60,
+                "member_count": 50,
+                "message_count": 50,
+                "name": "publicthread",
+                "owner_id": "5",
+                "parent_id": "2",
+                "rate_limit_per_user": 1000,
+                "thread_metadata": {
+                    "archive_timestamp": "archivetimestamp",
+                    "archived": false,
+                    "auto_archive_duration": AutoArchiveDuration::Day,
+                    "locked": false
+                }
+            }))
+            .unwrap()
+        )
+    }
+
+    #[test]
+    fn test_guild_private_thread_deserialization() {
+        let value = GuildChannel::PrivateThread(PrivateThread {
+            default_auto_archive_duration: Some(AutoArchiveDuration::Hour),
+            guild_id: Some(GuildId(1)),
+            id: ChannelId(6),
+            invitable: Some(true),
+            kind: ChannelType::GuildPrivateThread,
+            last_message_id: Some(MessageId(3)),
+            member: Some(ThreadMember {
+                flags: 0_u64,
+                id: Some(ChannelId(4)),
+                join_timestamp: "jointimestamp".into(),
+                member: None,
+                presence: None,
+                user_id: Some(UserId(5)),
+            }),
+            member_count: 50_u8,
+            message_count: 50_u8,
+            name: "privatethread".into(),
+            owner_id: Some(UserId(5)),
+            parent_id: Some(ChannelId(2)),
+            permission_overwrites: Vec::from([PermissionOverwrite {
+                allow: Permissions::empty(),
+                deny: Permissions::empty(),
+                kind: PermissionOverwriteType::Member(UserId(5)),
+            }]),
+            rate_limit_per_user: Some(1000_u64),
+            thread_metadata: ThreadMetadata {
+                archived: false,
+                auto_archive_duration: AutoArchiveDuration::Day,
+                archive_timestamp: "archivetimestamp".into(),
+                invitable: None,
+                locked: false,
+            },
+        });
+
+        assert_eq!(
+            value,
+            serde_json::from_value(serde_json::json!({
+                "id": "6",
+                "guild_id": "1",
+                "type": ChannelType::GuildPrivateThread,
+                "last_message_id": "3",
+                "member": {
+                    "flags": 0,
+                    "id": "4",
+                    "join_timestamp": "jointimestamp",
+                    "user_id": "5",
+                },
+                "default_auto_archive_duration": 60,
+                "invitable": true,
+                "member_count": 50,
+                "message_count": 50,
+                "name": "privatethread",
+                "owner_id": "5",
+                "parent_id": "2",
+                "rate_limit_per_user": 1000,
+                "thread_metadata": {
+                    "archive_timestamp": "archivetimestamp",
+                    "archived": false,
+                    "auto_archive_duration": AutoArchiveDuration::Day,
+                    "locked": false
+                },
+                "permission_overwrites": [
+                    {
+                        "allow": "0",
+                        "deny": "0",
+                        "type": 1,
+                        "id": "5"
+                    }
+                ]
+            }))
+            .unwrap()
+        )
+    }
 }
