@@ -55,6 +55,12 @@ pub enum DispatchEvent {
     StageInstanceCreate(StageInstanceCreate),
     StageInstanceDelete(StageInstanceDelete),
     StageInstanceUpdate(StageInstanceUpdate),
+    ThreadCreate(ThreadCreate),
+    ThreadDelete(ThreadDelete),
+    ThreadListSync(ThreadListSync),
+    ThreadMemberUpdate(ThreadMemberUpdate),
+    ThreadMembersUpdate(ThreadMembersUpdate),
+    ThreadUpdate(ThreadUpdate),
     TypingStart(Box<TypingStart>),
     UnavailableGuild(UnavailableGuild),
     UserUpdate(UserUpdate),
@@ -107,6 +113,12 @@ impl DispatchEvent {
             Self::StageInstanceCreate(_) => EventType::StageInstanceCreate,
             Self::StageInstanceDelete(_) => EventType::StageInstanceDelete,
             Self::StageInstanceUpdate(_) => EventType::StageInstanceUpdate,
+            Self::ThreadCreate(_) => EventType::ThreadCreate,
+            Self::ThreadDelete(_) => EventType::ThreadDelete,
+            Self::ThreadListSync(_) => EventType::ThreadListSync,
+            Self::ThreadMemberUpdate(_) => EventType::ThreadMemberUpdate,
+            Self::ThreadMembersUpdate(_) => EventType::ThreadMembersUpdate,
+            Self::ThreadUpdate(_) => EventType::ThreadUpdate,
             Self::TypingStart(_) => EventType::TypingStart,
             Self::UnavailableGuild(_) => EventType::UnavailableGuild,
             Self::UserUpdate(_) => EventType::UserUpdate,
@@ -162,6 +174,12 @@ impl TryFrom<Event> for DispatchEvent {
             Event::StageInstanceCreate(v) => Self::StageInstanceCreate(v),
             Event::StageInstanceDelete(v) => Self::StageInstanceDelete(v),
             Event::StageInstanceUpdate(v) => Self::StageInstanceUpdate(v),
+            Event::ThreadCreate(v) => Self::ThreadCreate(v),
+            Event::ThreadDelete(v) => Self::ThreadDelete(v),
+            Event::ThreadListSync(v) => Self::ThreadListSync(v),
+            Event::ThreadMemberUpdate(v) => Self::ThreadMemberUpdate(v),
+            Event::ThreadMembersUpdate(v) => Self::ThreadMembersUpdate(v),
+            Event::ThreadUpdate(v) => Self::ThreadUpdate(v),
             Event::TypingStart(v) => Self::TypingStart(v),
             Event::UnavailableGuild(v) => Self::UnavailableGuild(v),
             Event::UserUpdate(v) => Self::UserUpdate(v),
@@ -313,6 +331,24 @@ impl<'de, 'a> DeserializeSeed<'de> for DispatchEventWithTypeDeserializer<'a> {
             "STAGE_INSTANCE_UPDATE" => {
                 DispatchEvent::StageInstanceUpdate(StageInstanceUpdate::deserialize(deserializer)?)
             }
+            "THREAD_CREATE" => {
+                DispatchEvent::ThreadCreate(ThreadCreate::deserialize(deserializer)?)
+            }
+            "THREAD_DELETE" => {
+                DispatchEvent::ThreadDelete(ThreadDelete::deserialize(deserializer)?)
+            }
+            "THREAD_LIST_SYNC" => {
+                DispatchEvent::ThreadListSync(ThreadListSync::deserialize(deserializer)?)
+            }
+            "THREAD_MEMBER_UPDATE" => {
+                DispatchEvent::ThreadMemberUpdate(ThreadMemberUpdate::deserialize(deserializer)?)
+            }
+            "THREAD_MEMBERS_UPDATE" => {
+                DispatchEvent::ThreadMembersUpdate(ThreadMembersUpdate::deserialize(deserializer)?)
+            }
+            "THREAD_UPDATE" => {
+                DispatchEvent::ThreadUpdate(ThreadUpdate::deserialize(deserializer)?)
+            }
             "TYPING_START" => {
                 DispatchEvent::TypingStart(Box::new(TypingStart::deserialize(deserializer)?))
             }
