@@ -41,6 +41,12 @@ mod role_update;
 mod stage_instance_create;
 mod stage_instance_delete;
 mod stage_instance_update;
+mod thread_create;
+mod thread_delete;
+mod thread_list_sync;
+mod thread_member_update;
+mod thread_members_update;
+mod thread_update;
 mod typing_start;
 mod unavailable_guild;
 mod update_voice_state;
@@ -66,7 +72,9 @@ pub use self::{
     request_guild_members::RequestGuildMembers, role_create::RoleCreate, role_delete::RoleDelete,
     role_update::RoleUpdate, stage_instance_create::StageInstanceCreate,
     stage_instance_delete::StageInstanceDelete, stage_instance_update::StageInstanceUpdate,
-    typing_start::TypingStart, unavailable_guild::UnavailableGuild,
+    thread_create::ThreadCreate, thread_delete::ThreadDelete, thread_list_sync::ThreadListSync,
+    thread_member_update::ThreadMemberUpdate, thread_members_update::ThreadMembersUpdate,
+    thread_update::ThreadUpdate, typing_start::TypingStart, unavailable_guild::UnavailableGuild,
     update_presence::UpdatePresence, update_voice_state::UpdateVoiceState, user_update::UserUpdate,
     voice_server_update::VoiceServerUpdate, voice_state_update::VoiceStateUpdate,
     webhooks_update::WebhooksUpdate,
